# `nix run microvm#vm`
{
  inputs,
  lib,
  system,
}:
lib.nixosSystem {
  inherit system;

  modules = [
    # for declarative MicroVM management
    inputs.microvm.nixosModules.host
    # this runs as a MicroVM that nests MicroVMs
    inputs.microvm.nixosModules.microvm

    (
      {
        config,
        lib,
        pkgs,
        ...
      }:
      let
        hypervisors = [ "qemu" ];

        hypervisorMacAddrs = builtins.listToAttrs (
          map (
            hypervisor:
            let
              hash = builtins.hashString "sha256" hypervisor;
              c = off: builtins.substring off 2 hash;
              mac = "${builtins.substring 0 1 hash}2:${c 2}:${c 4}:${c 6}:${c 8}:${c 10}";
            in
            {
              name = hypervisor;
              value = mac;
            }
          ) hypervisors
        );

        hypervisorIPv4Addrs = builtins.listToAttrs (
          lib.imap0 (i: hypervisor: {
            name = hypervisor;
            value = "10.0.0.${toString (2 + i)}";
          }) hypervisors
        );
      in
      {
        networking.hostName = "microvms-host";
        system.stateVersion = config.system.nixos.version;
        users.users.root.password = "";
        users.motd = ''
          MicroVM configured to allow SSH login with an empty root
          password.
        '';
        services.getty.autologinUser = "root";

        # MicroVM settings
        microvm = {
          mem = 8192;
          vcpu = 4;
          # Use QEMU because nested virtualization and user networking
          # are required.
          shares = [
            {
              tag = "ro-store";
              source = "/nix/store";
              mountPoint = "/nix/.ro-store";
            }
          ];
          hypervisor = "qemu";
          interfaces = [
            {
              type = "user";
              id = "qemu";
              mac = "02:00:00:01:01:01";
            }
          ];
        };

        # systemd.services.personal-startup = {
        #   description = "My Startup Script";
        #   script = ''
        #     sleep 60
        #     shutdown now
        #   '';
        #   wantedBy = [ "forgejo.service" ];
        # };

        environment.systemPackages = [ pkgs.curl ];

        services.forgejo = {
          enable = true;
          package = pkgs.forgejo;

          # default settings from nixos options page
          settings = {
            DEFAULT = {
              RUN_MODE = "dev";
            };
            "cron.sync_external_users" = {
              RUN_AT_START = true;
              SCHEDULE = "@every 24h";
              UPDATE_EXISTING = true;
            };
            mailer = {
              ENABLED = true;
              PROTOCOL = "sendmail";
              # FIXME: use valid email
              FROM = "do-not-reply@example.com";
              SENDMAIL_PATH = "${pkgs.system-sendmail}/bin/sendmail";
            };
            other = {
              SHOW_FOOTER_VERSION = false;
            };

            service = {
              REGISTER_MANUAL_CONFIRM = true;
              # FIXME: doesn't work since mailer doesn't work yet
              ENABLE_NOTIFY_EMAIL = true;
            };
            repository = {
              DEFAULT_REPO_UNITS = "repo.code,repo.releases,repo.issues,repo.pulls,repo.projects,repo.actions";
            };
            # server = {
            #   ROOT_URL = "https://${forgejo-site}";
            #   SSH_PORT = config.ssh.port;
            # };
          };

          database = {
            type = "postgres";
          };
        };
      }
    )
  ];
}
